package main

import (
	"MacFastLookup/service"
	"embed"

	"github.com/wailsapp/wails/v2"
	"github.com/wailsapp/wails/v2/pkg/options"
	"github.com/wailsapp/wails/v2/pkg/options/assetserver"
	"github.com/wailsapp/wails/v2/pkg/options/mac"
)

//go:embed all:frontend/dist
var assets embed.FS

func main() {
	// Create an instance of the app structure
	app := NewApp()

	// Create service
	dbService := service.NewSQLiteHelper()

	// create update service
	updateService := service.NewUpdateService("https://tools.taurusxin.com/macfastlookup/latest_version.txt")

	// Create application with options
	err := wails.Run(&options.App{
		Title:  "MacFastLookup",
		Width:  540,
		Height: 375,
		AssetServer: &assetserver.Options{
			Assets: assets,
		},
		BackgroundColour: &options.RGBA{R: 27, G: 38, B: 54, A: 1},
		OnStartup:        app.startup,
		Bind: []interface{}{
			app,
			dbService,
			updateService,
		},
		Mac: &mac.Options{
			TitleBar: &mac.TitleBar{
				FullSizeContent: true,
			},
		},
	})

	if err != nil {
		println("Error:", err.Error())
	}
}
